@@ -16,34 +16,17 @@
 
 """Map from Git sha's to Bazaar objects."""
 
-from dulwich.objects import (
-    sha_to_hex,
-    hex_to_sha,
-    )
 import os
 import threading
 
-from dulwich.objects import (
-    ShaFile,
-    )
+from dulwich.objects import ShaFile, hex_to_sha, sha_to_hex
 
-from .. import (
-    bedding,
-    errors as bzr_errors,
-    osutils,
-    registry,
-    trace,
-    )
-from ..bzr import (
-    btree_index as _mod_btree_index,
-    index as _mod_index,
-    versionedfile,
-    )
-from ..transport import (
-    get_transport_from_path,
-    FileExists,
-    NoSuchFile,
-    )
+from .. import bedding, osutils, registry, trace
+from .. import errors as bzr_errors
+from ..bzr import btree_index as _mod_btree_index
+from ..bzr import index as _mod_index
+from ..bzr import versionedfile
+from ..transport import FileExists, NoSuchFile, get_transport_from_path
 
 
 def get_cache_dir():
@@ -67,30 +50,6 @@ def get_remote_cache_transport(repository):
     return get_transport_from_path(path)
 
 
-def check_pysqlite_version(sqlite3):
-    """Check that sqlite library is compatible.
-
-    """
-    if (sqlite3.sqlite_version_info[0] < 3
-            or (sqlite3.sqlite_version_info[0] == 3 and
-                sqlite3.sqlite_version_info[1] < 3)):
-        trace.warning('Needs at least sqlite 3.3.x')
-        raise bzr_errors.BzrError("incompatible sqlite library")
-
-
-try:
-    try:
-        import sqlite3
-        check_pysqlite_version(sqlite3)
-    except (ImportError, bzr_errors.BzrError):
-        from pysqlite2 import dbapi2 as sqlite3
-        check_pysqlite_version(sqlite3)
-except BaseException:
-    trace.warning('Needs at least Python2.5 or Python2.4 with the pysqlite2 '
-                  'module')
-    raise bzr_errors.BzrError("missing sqlite library")
-
-
 _mapdbs = threading.local()
 
 
@@ -103,7 +62,7 @@ def mapdbs():
         return _mapdbs.cache
 
 
-class GitShaMap(object):
+class GitShaMap:
     """Git<->Bzr revision id mapping database."""
 
     def lookup_git_sha(self, sha):
@@ -112,7 +71,7 @@ class GitShaMap(object):
         :return: list with (type, type_data) tuples with type_data:
             commit: revid, tree_sha, verifiers
             blob: fileid, revid
-            tree: fileid, revid
+            tree: fileid, revid.
         """
         raise NotImplementedError(self.lookup_git_sha)
 
@@ -125,13 +84,11 @@ class GitShaMap(object):
         raise NotImplementedError(self.lookup_blob_id)
 
     def lookup_tree_id(self, file_id, revision):
-        """Retrieve a Git tree SHA by file id.
-        """
+        """Retrieve a Git tree SHA by file id."""
         raise NotImplementedError(self.lookup_tree_id)
 
     def lookup_commit(self, revid):
-        """Retrieve a Git commit SHA by Bazaar revision id.
-        """
+        """Retrieve a Git commit SHA by Bazaar revision id."""
         raise NotImplementedError(self.lookup_commit)
 
     def revids(self):
@@ -159,7 +116,7 @@ class GitShaMap(object):
         """Abort any pending changes."""
 
 
-class ContentCache(object):
+class ContentCache:
     """Object that can cache Git objects."""
 
     def add(self, object):
@@ -176,7 +133,7 @@ class ContentCache(object):
         raise NotImplementedError(self.__getitem__)
 
 
-class BzrGitCacheFormat(object):
+class BzrGitCacheFormat:
     """Bazaar-Git Cache Format."""
 
     def get_format_string(self):
@@ -189,7 +146,7 @@ class BzrGitCacheFormat(object):
 
     def initialize(self, transport):
         """Create a new instance of this cache format at transport."""
-        transport.put_bytes('format', self.get_format_string())
+        transport.put_bytes("format", self.get_format_string())
 
     @classmethod
     def from_transport(self, transport):
@@ -199,10 +156,10 @@ class BzrGitCacheFormat(object):
         :return: A BzrGitCache instance
         """
         try:
-            format_name = transport.get_bytes('format')
+            format_name = transport.get_bytes("format")
             format = formats.get(format_name)
         except NoSuchFile:
-            format = formats.get('default')
+            format = formats.get("default")
             format.initialize(transport)
         return format.open(transport)
 
@@ -218,22 +175,21 @@ class BzrGitCacheFormat(object):
         :return: A `BzrGitCache`
         """
         from ..transport.local import LocalTransport
+
         repo_transport = getattr(repository, "_transport", None)
-        if (repo_transport is not None
-                and isinstance(repo_transport, LocalTransport)):
+        if repo_transport is not None and isinstance(repo_transport, LocalTransport):
             # Even if we don't write to this repo, we should be able
             # to update its cache.
             try:
-                repo_transport = remove_readonly_transport_decorator(
-                    repo_transport)
+                repo_transport = remove_readonly_transport_decorator(repo_transport)
             except bzr_errors.ReadOnlyError:
                 transport = None
             else:
                 try:
-                    repo_transport.mkdir('git')
+                    repo_transport.mkdir("git")
                 except FileExists:
                     pass
-                transport = repo_transport.clone('git')
+                transport = repo_transport.clone("git")
         else:
             transport = None
         if transport is None:
@@ -241,7 +197,7 @@ class BzrGitCacheFormat(object):
         return cls.from_transport(transport)
 
 
-class CacheUpdater(object):
+class CacheUpdater:
     """Base class for objects that can update a bzr-git cache."""
 
     def add_object(self, obj, bzr_key_data, path):
@@ -258,7 +214,7 @@ class CacheUpdater(object):
         raise NotImplementedError(self.finish)
 
 
-class BzrGitCache(object):
+class BzrGitCache:
     """Caching backend."""
 
     def __init__(self, idmap, cache_updater_klass):
@@ -290,7 +246,7 @@ class DictCacheUpdater(CacheUpdater):
         if isinstance(obj, tuple):
             (type_name, hexsha) = obj
         else:
-            type_name = obj.type_name.decode('ascii')
+            type_name = obj.type_name.decode("ascii")
             hexsha = obj.id
         if not isinstance(hexsha, bytes):
             raise TypeError(hexsha)
@@ -305,7 +261,8 @@ class DictCacheUpdater(CacheUpdater):
             if bzr_key_data is not None:
                 key = type_data = bzr_key_data
                 self.cache.idmap._by_fileid.setdefault(type_data[1], {})[
-                    type_data[0]] = hexsha
+                    type_data[0]
+                ] = hexsha
         else:
             raise AssertionError
         entry = (type_name, type_data)
@@ -331,8 +288,7 @@ class DictGitShaMap(GitShaMap):
     def lookup_git_sha(self, sha):
         if not isinstance(sha, bytes):
             raise TypeError(sha)
-        for entry in self._by_sha[sha].values():
-            yield entry
+        yield from self._by_sha[sha].values()
 
     def lookup_tree_id(self, fileid, revision):
         return self._by_fileid[revision][fileid]
@@ -341,8 +297,8 @@ class DictGitShaMap(GitShaMap):
         return self._by_revid[revid]
 
     def revids(self):
-        for key, entries in self._by_sha.items():
-            for (type, type_data) in entries.values():
+        for _key, entries in self._by_sha.items():
+            for type, type_data in entries.values():
                 if type == "commit":
                     yield type_data[0]
 
@@ -351,7 +307,6 @@ class DictGitShaMap(GitShaMap):
 
 
 class SqliteCacheUpdater(CacheUpdater):
-
     def __init__(self, cache, rev):
         self.cache = cache
         self.db = self.cache.idmap.db
@@ -364,7 +319,7 @@ class SqliteCacheUpdater(CacheUpdater):
         if isinstance(obj, tuple):
             (type_name, hexsha) = obj
         else:
-            type_name = obj.type_name.decode('ascii')
+            type_name = obj.type_name.decode("ascii")
             hexsha = obj.id
         if not isinstance(hexsha, bytes):
             raise TypeError(hexsha)
@@ -386,16 +341,16 @@ class SqliteCacheUpdater(CacheUpdater):
         if self._commit is None:
             raise AssertionError("No commit object added")
         self.db.executemany(
-            "replace into trees (sha1, fileid, revid) values (?, ?, ?)",
-            self._trees)
+            "replace into trees (sha1, fileid, revid) values (?, ?, ?)", self._trees
+        )
         self.db.executemany(
-            "replace into blobs (sha1, fileid, revid) values (?, ?, ?)",
-            self._blobs)
+            "replace into blobs (sha1, fileid, revid) values (?, ?, ?)", self._blobs
+        )
         self.db.execute(
             "replace into commits (sha1, revid, tree_sha, testament3_sha1) "
             "values (?, ?, ?, ?)",
-            (self._commit.id, self.revid, self._commit.tree,
-                self._testament3_sha1))
+            (self._commit.id, self.revid, self._commit.tree, self._testament3_sha1),
+        )
         return self._commit
 
 
@@ -404,9 +359,8 @@ def SqliteBzrGitCache(p):
 
 
 class SqliteGitCacheFormat(BzrGitCacheFormat):
-
     def get_format_string(self):
-        return b'bzr-git sha map version 1 using sqlite\n'
+        return b"bzr-git sha map version 1 using sqlite\n"
 
     def open(self, transport):
         try:
@@ -420,6 +374,8 @@ class SqliteGitShaMap(GitShaMap):
     """Bazaar GIT Sha map that uses a sqlite database for storage."""
 
     def __init__(self, path=None):
+        import sqlite3
+
         self.path = path
         if path is None:
             self.db = sqlite3.connect(":memory:")
@@ -454,17 +410,15 @@ class SqliteGitShaMap(GitShaMap):
             fileid, revid);
 """)
         try:
-            self.db.executescript(
-                "ALTER TABLE commits ADD testament3_sha1 TEXT;")
+            self.db.executescript("ALTER TABLE commits ADD testament3_sha1 TEXT;")
         except sqlite3.OperationalError:
             pass  # Column already exists.
 
     def __repr__(self):
-        return "%s(%r)" % (self.__class__.__name__, self.path)
+        return "{}({!r})".format(self.__class__.__name__, self.path)
 
     def lookup_commit(self, revid):
-        cursor = self.db.execute("select sha1 from commits where revid = ?",
-                                 (revid,))
+        cursor = self.db.execute("select sha1 from commits where revid = ?", (revid,))
         row = cursor.fetchone()
         if row is not None:
             return row[0]
@@ -475,16 +429,16 @@ class SqliteGitShaMap(GitShaMap):
 
     def lookup_blob_id(self, fileid, revision):
         row = self.db.execute(
-            "select sha1 from blobs where fileid = ? and revid = ?",
-            (fileid, revision)).fetchone()
+            "select sha1 from blobs where fileid = ? and revid = ?", (fileid, revision)
+        ).fetchone()
         if row is not None:
             return row[0]
         raise KeyError(fileid)
 
     def lookup_tree_id(self, fileid, revision):
         row = self.db.execute(
-            "select sha1 from trees where fileid = ? and revid = ?",
-            (fileid, revision)).fetchone()
+            "select sha1 from trees where fileid = ? and revid = ?", (fileid, revision)
+        ).fetchone()
         if row is not None:
             return row[0]
         raise KeyError(fileid)
@@ -500,8 +454,9 @@ class SqliteGitShaMap(GitShaMap):
         """
         found = False
         cursor = self.db.execute(
-            "select revid, tree_sha, testament3_sha1 from commits where "
-            "sha1 = ?", (sha,))
+            "select revid, tree_sha, testament3_sha1 from commits where sha1 = ?",
+            (sha,),
+        )
         for row in cursor.fetchall():
             found = True
             if row[2] is not None:
@@ -510,12 +465,14 @@ class SqliteGitShaMap(GitShaMap):
                 verifiers = {}
             yield ("commit", (row[0], row[1], verifiers))
         cursor = self.db.execute(
-            "select fileid, revid from blobs where sha1 = ?", (sha,))
+            "select fileid, revid from blobs where sha1 = ?", (sha,)
+        )
         for row in cursor.fetchall():
             found = True
             yield ("blob", row)
         cursor = self.db.execute(
-            "select fileid, revid from trees where sha1 = ?", (sha,))
+            "select fileid, revid from trees where sha1 = ?", (sha,)
+        )
         for row in cursor.fetchall():
             found = True
             yield ("tree", row)
@@ -529,8 +486,8 @@ class SqliteGitShaMap(GitShaMap):
     def sha1s(self):
         """List the SHA1s."""
         for table in ("blobs", "commits", "trees"):
-            for (sha,) in self.db.execute("select sha1 from %s" % table):
-                yield sha.encode('ascii')
+            for (sha,) in self.db.execute("select sha1 from {}".format(table)):  # noqa: S608
+                yield sha.encode("ascii")
 
 
 class TdbCacheUpdater(CacheUpdater):
@@ -549,7 +506,7 @@ class TdbCacheUpdater(CacheUpdater):
             (type_name, hexsha) = obj
             sha = hex_to_sha(hexsha)
         else:
-            type_name = obj.type_name.decode('ascii')
+            type_name = obj.type_name.decode("ascii")
             sha = obj.sha().digest()
         if type_name == "commit":
             self.db[b"commit\0" + self.revid] = b"\0".join((sha, obj.tree))
@@ -564,8 +521,7 @@ class TdbCacheUpdater(CacheUpdater):
         elif type_name == "blob":
             if bzr_key_data is None:
                 return
-            self.db[b"\0".join(
-                (b"blob", bzr_key_data[0], bzr_key_data[1]))] = sha
+            self.db[b"\0".join((b"blob", bzr_key_data[0], bzr_key_data[1]))] = sha
             type_data = bzr_key_data
         elif type_name == "tree":
             if bzr_key_data is None:
@@ -573,14 +529,14 @@ class TdbCacheUpdater(CacheUpdater):
             type_data = bzr_key_data
         else:
             raise AssertionError
-        entry = b"\0".join((type_name.encode('ascii'), ) + type_data) + b"\n"
+        entry = b"\0".join((type_name.encode("ascii"),) + type_data) + b"\n"
         key = b"git\0" + sha
         try:
             oldval = self.db[key]
         except KeyError:
             self.db[key] = entry
         else:
-            if not oldval.endswith(b'\n'):
+            if not oldval.endswith(b"\n"):
                 self.db[key] = b"".join([oldval, b"\n", entry])
             else:
                 self.db[key] = b"".join([oldval, entry])
@@ -599,7 +555,7 @@ class TdbGitCacheFormat(BzrGitCacheFormat):
     """Cache format for tdb-based caches."""
 
     def get_format_string(self):
-        return b'bzr-git sha map version 3 using tdb\n'
+        return b"bzr-git sha map version 3 using tdb\n"
 
     def open(self, transport):
         try:
@@ -610,8 +566,8 @@ class TdbGitCacheFormat(BzrGitCacheFormat):
             return TdbBzrGitCache(os.path.join(basepath, "idmap.tdb"))
         except ImportError:
             raise ImportError(
-                "Unable to open existing bzr-git cache because 'tdb' is not "
-                "installed.")
+                "Unable to open existing bzr-git cache because 'tdb' is not installed."
+            )
 
 
 class TdbGitShaMap(GitShaMap):
@@ -630,23 +586,27 @@ class TdbGitShaMap(GitShaMap):
 
     def __init__(self, path=None):
         import tdb
+
         self.path = path
         if path is None:
             self.db = {}
         else:
             if path not in mapdbs():
-                mapdbs()[path] = tdb.Tdb(path, self.TDB_HASH_SIZE, tdb.DEFAULT,
-                                         os.O_RDWR | os.O_CREAT)
+                mapdbs()[path] = tdb.Tdb(
+                    path, self.TDB_HASH_SIZE, tdb.DEFAULT, os.O_RDWR | os.O_CREAT
+                )
             self.db = mapdbs()[path]
         try:
             if int(self.db[b"version"]) not in (2, 3):
                 trace.warning(
                     "SHA Map is incompatible (%s -> %d), rebuilding database.",
-                    self.db[b"version"], self.TDB_MAP_VERSION)
+                    self.db[b"version"],
+                    self.TDB_MAP_VERSION,
+                )
                 self.db.clear()
         except KeyError:
             pass
-        self.db[b"version"] = b'%d' % self.TDB_MAP_VERSION
+        self.db[b"version"] = b"%d" % self.TDB_MAP_VERSION
 
     def start_write_group(self):
         """Start writing changes."""
@@ -661,13 +621,13 @@ class TdbGitShaMap(GitShaMap):
         self.db.transaction_cancel()
 
     def __repr__(self):
-        return "%s(%r)" % (self.__class__.__name__, self.path)
+        return "{}({!r})".format(self.__class__.__name__, self.path)
 
     def lookup_commit(self, revid):
         try:
             return sha_to_hex(self.db[b"commit\0" + revid][:20])
         except KeyError:
-            raise KeyError("No cache entry for %r" % revid)
+            raise KeyError("No cache entry for {!r}".format(revid))
 
     def lookup_blob_id(self, fileid, revision):
         return sha_to_hex(self.db[b"\0".join((b"blob", fileid, revision))])
@@ -686,17 +646,16 @@ class TdbGitShaMap(GitShaMap):
         value = self.db[b"git\0" + sha]
         for data in value.splitlines():
             data = data.split(b"\0")
-            type_name = data[0].decode('ascii')
+            type_name = data[0].decode("ascii")
             if type_name == "commit":
                 if len(data) == 3:
                     yield (type_name, (data[1], data[2], {}))
                 else:
-                    yield (type_name, (data[1], data[2],
-                                       {"testament3-sha1": data[3]}))
+                    yield (type_name, (data[1], data[2], {"testament3-sha1": data[3]}))
             elif type_name in ("tree", "blob"):
                 yield (type_name, tuple(data[1:]))
             else:
-                raise AssertionError("unknown type %r" % type_name)
+                raise AssertionError("unknown type {!r}".format(type_name))
 
     def missing_revisions(self, revids):
         ret = set()
@@ -722,25 +681,27 @@ class TdbGitShaMap(GitShaMap):
 
 
 class VersionedFilesContentCache(ContentCache):
-
     def __init__(self, vf):
         self._vf = vf
 
     def add(self, obj):
         self._vf.insert_record_stream(
-            [versionedfile.ChunkedContentFactory(
-                (obj.id,), [], None, obj.as_legacy_object_chunks())])
+            [
+                versionedfile.ChunkedContentFactory(
+                    (obj.id,), [], None, obj.as_legacy_object_chunks()
+                )
+            ]
+        )
 
     def __getitem__(self, sha):
-        stream = self._vf.get_record_stream([(sha,)], 'unordered', True)
+        stream = self._vf.get_record_stream([(sha,)], "unordered", True)
         entry = next(stream)
-        if entry.storage_kind == 'absent':
+        if entry.storage_kind == "absent":
             raise KeyError(sha)
-        return ShaFile._parse_legacy_object(entry.get_bytes_as('fulltext'))
+        return ShaFile._parse_legacy_object(entry.get_bytes_as("fulltext"))
 
 
 class IndexCacheUpdater(CacheUpdater):
-
     def __init__(self, cache, rev):
         self.cache = cache
         self.revid = rev.revision_id
@@ -752,20 +713,23 @@ class IndexCacheUpdater(CacheUpdater):
         if isinstance(obj, tuple):
             (type_name, hexsha) = obj
         else:
-            type_name = obj.type_name.decode('ascii')
+            type_name = obj.type_name.decode("ascii")
             hexsha = obj.id
         if type_name == "commit":
             self._commit = obj
             if type(bzr_key_data) is not dict:
                 raise TypeError(bzr_key_data)
-            self.cache.idmap._add_git_sha(hexsha, b"commit",
-                                          (self.revid, obj.tree, bzr_key_data))
-            self.cache.idmap._add_node((b"commit", self.revid, b"X"),
-                                       b" ".join((hexsha, obj.tree)))
+            self.cache.idmap._add_git_sha(
+                hexsha, b"commit", (self.revid, obj.tree, bzr_key_data)
+            )
+            self.cache.idmap._add_node(
+                (b"commit", self.revid, b"X"), b" ".join((hexsha, obj.tree))
+            )
         elif type_name == "blob":
             self.cache.idmap._add_git_sha(hexsha, b"blob", bzr_key_data)
-            self.cache.idmap._add_node((b"blob", bzr_key_data[0],
-                                        bzr_key_data[1]), hexsha)
+            self.cache.idmap._add_node(
+                (b"blob", bzr_key_data[0], bzr_key_data[1]), hexsha
+            )
         elif type_name == "tree":
             self.cache.idmap._add_git_sha(hexsha, b"tree", bzr_key_data)
         else:
@@ -776,23 +740,22 @@ class IndexCacheUpdater(CacheUpdater):
 
 
 class IndexBzrGitCache(BzrGitCache):
-
     def __init__(self, transport=None):
-        shamap = IndexGitShaMap(transport.clone('index'))
-        super(IndexBzrGitCache, self).__init__(shamap, IndexCacheUpdater)
+        shamap = IndexGitShaMap(transport.clone("index"))
+        super().__init__(shamap, IndexCacheUpdater)
 
 
 class IndexGitCacheFormat(BzrGitCacheFormat):
-
     def get_format_string(self):
-        return b'bzr-git sha map with git object cache version 1\n'
+        return b"bzr-git sha map with git object cache version 1\n"
 
     def initialize(self, transport):
-        super(IndexGitCacheFormat, self).initialize(transport)
-        transport.mkdir('index')
-        transport.mkdir('objects')
+        super().initialize(transport)
+        transport.mkdir("index")
+        transport.mkdir("objects")
         from .transportgit import TransportObjectStore
-        TransportObjectStore.init(transport.clone('objects'))
+
+        TransportObjectStore.init(transport.clone("objects"))
 
     def open(self, transport):
         return IndexBzrGitCache(transport)
@@ -823,7 +786,8 @@ class IndexGitShaMap(GitShaMap):
                 if not name.endswith(".rix"):
                     continue
                 x = _mod_btree_index.BTreeGraphIndex(
-                    self._transport, name, self._transport.stat(name).st_size)
+                    self._transport, name, self._transport.stat(name).st_size
+                )
                 self._index.insert_index(0, x)
 
     @classmethod
@@ -831,43 +795,43 @@ class IndexGitShaMap(GitShaMap):
         transport = getattr(repository, "_transport", None)
         if transport is not None:
             try:
-                transport.mkdir('git')
+                transport.mkdir("git")
             except FileExists:
                 pass
-            return cls(transport.clone('git'))
+            return cls(transport.clone("git"))
         return cls(get_transport_from_path(get_cache_dir()))
 
     def __repr__(self):
         if self._transport is not None:
-            return "%s(%r)" % (self.__class__.__name__, self._transport.base)
+            return "{}({!r})".format(self.__class__.__name__, self._transport.base)
         else:
-            return "%s()" % (self.__class__.__name__)
+            return "{}()".format(self.__class__.__name__)
 
     def repack(self):
         if self._builder is not None:
-            raise bzr_errors.BzrError('builder already open')
+            raise bzr_errors.BzrError("builder already open")
         self.start_write_group()
         self._builder.add_nodes(
-            ((key, value) for (_, key, value) in
-                self._index.iter_all_entries()))
+            (key, value) for (_, key, value) in self._index.iter_all_entries()
+        )
         to_remove = []
-        for name in self._transport.list_dir('.'):
-            if name.endswith('.rix'):
+        for name in self._transport.list_dir("."):
+            if name.endswith(".rix"):
                 to_remove.append(name)
         self.commit_write_group()
         del self._index.indices[1:]
         for name in to_remove:
-            self._transport.rename(name, name + '.old')
+            self._transport.rename(name, name + ".old")
 
     def start_write_group(self):
         if self._builder is not None:
-            raise bzr_errors.BzrError('builder already open')
+            raise bzr_errors.BzrError("builder already open")
         self._builder = _mod_btree_index.BTreeBuilder(0, key_elements=3)
         self._name = osutils.sha()
 
     def commit_write_group(self):
         if self._builder is None:
-            raise bzr_errors.BzrError('builder not open')
+            raise bzr_errors.BzrError("builder not open")
         stream = self._builder.finish()
         name = self._name.hexdigest() + ".rix"
         size = self._transport.put_file(name, stream)
@@ -878,7 +842,7 @@ class IndexGitShaMap(GitShaMap):
 
     def abort_write_group(self):
         if self._builder is None:
-            raise bzr_errors.BzrError('builder not open')
+            raise bzr_errors.BzrError("builder not open")
         self._builder = None
         self._name = None
 
@@ -949,36 +913,34 @@ class IndexGitShaMap(GitShaMap):
                 verifiers = {}
             yield ("commit", (data[1], data[2], verifiers))
         else:
-            yield (data[0].decode('ascii'), tuple(data[1:]))
+            yield (data[0].decode("ascii"), tuple(data[1:]))
 
     def revids(self):
         """List the revision ids known."""
-        for key, value in self._iter_entries_prefix((b"commit", None, None)):
+        for key, _value in self._iter_entries_prefix((b"commit", None, None)):
             yield key[1]
 
     def missing_revisions(self, revids):
         """Return set of all the revisions that are not present."""
         missing_revids = set(revids)
-        for _, key, value in self._index.iter_entries((
-                (b"commit", revid, b"X") for revid in revids)):
+        for _, key, _value in self._index.iter_entries(
+            (b"commit", revid, b"X") for revid in revids
+        ):
             missing_revids.remove(key[1])
         return missing_revids
 
     def sha1s(self):
         """List the SHA1s."""
-        for key, value in self._iter_entries_prefix((b"git", None, None)):
+        for key, _value in self._iter_entries_prefix((b"git", None, None)):
             yield key[1]
 
 
-formats = registry.Registry()
-formats.register(TdbGitCacheFormat().get_format_string(),
-                 TdbGitCacheFormat())
-formats.register(SqliteGitCacheFormat().get_format_string(),
-                 SqliteGitCacheFormat())
-formats.register(IndexGitCacheFormat().get_format_string(),
-                 IndexGitCacheFormat())
+formats = registry.Registry[str, BzrGitCacheFormat]()
+formats.register(TdbGitCacheFormat().get_format_string(), TdbGitCacheFormat())
+formats.register(SqliteGitCacheFormat().get_format_string(), SqliteGitCacheFormat())
+formats.register(IndexGitCacheFormat().get_format_string(), IndexGitCacheFormat())
 # In the future, this will become the default:
-formats.register('default', IndexGitCacheFormat())
+formats.register("default", IndexGitCacheFormat())
 
 
 def migrate_ancient_formats(repo_transport):
