@@ -17,20 +17,14 @@
 """InterRepository operations."""
 
 import itertools
-from typing import Callable, Optional
+from collections.abc import Callable
 
 from dulwich.errors import NotCommitError
 from dulwich.object_store import ObjectStoreGraphWalker
 from dulwich.objects import ObjectID
 from dulwich.pack import PACK_SPOOL_FILE_MAX_SIZE
-from dulwich.protocol import CAPABILITY_THIN_PACK, ZERO_SHA
+from dulwich.protocol import CAPABILITY_THIN_PACK, PEELED_TAG_SUFFIX, ZERO_SHA
 from dulwich.refs import SYMREF
-
-try:
-    from dulwich.refs import PEELED_TAG_SUFFIX
-except ImportError:  # dulwich < 0.21.3
-    from dulwich.refs import ANNOTATED_TAG_SUFFIX as PEELED_TAG_SUFFIX
-
 from dulwich.walk import Walker
 
 from .. import config, trace, ui
@@ -54,7 +48,7 @@ from .remote import RemoteGitError, RemoteGitRepository
 from .repository import GitRepository, GitRepositoryFormat, LocalGitRepository
 from .unpeel_map import UnpeelMap
 
-EitherId = tuple[Optional[RevisionID], Optional[ObjectID]]
+EitherId = tuple[RevisionID | None, ObjectID | None]
 EitherRefDict = dict[bytes, EitherId]
 RevidMap = dict[RevisionID, tuple[ObjectID, RevisionID]]
 
@@ -278,7 +272,7 @@ class InterToLocalGitRepository(InterToGitRepository):
                     )
         return revidmap, old_refs, result_refs
 
-    def fetch_revs(self, revs, lossy: bool, limit: Optional[int] = None) -> RevidMap:
+    def fetch_revs(self, revs, lossy: bool, limit: int | None = None) -> RevidMap:
         if not lossy and not self.mapping.roundtripping:
             for _git_sha, bzr_revid in revs:
                 if bzr_revid is not None and needs_roundtripping(
@@ -366,16 +360,8 @@ class InterToRemoteGitRepository(InterToGitRepository):
 
         self._warn_slow()
         with self.source_store.lock_read():
-            # Wrapper to adapt generate_lossy_pack_data signature for dulwich >= 0.22
-            # Client expects: (have, want, ofs_delta)
-            # Method provides: (have, want, shallow=None, progress=None, get_tagged=None, ofs_delta=False)
-            def generate_pack_data_wrapper(have, want, ofs_delta=True):
-                return self.source_store.generate_lossy_pack_data(
-                    have, want, shallow=None, progress=None, get_tagged=None, ofs_delta=ofs_delta
-                )
-
             result = self.target.send_pack(
-                git_update_refs, generate_pack_data_wrapper
+                git_update_refs, self.source_store.generate_lossy_pack_data
             )
             for ref, error in result.ref_status.items():
                 if error:
@@ -439,7 +425,7 @@ class InterFromGitRepository(InterRepository):
 
         return determine_wants
 
-    def determine_wants_all(self, refs, depth=None):
+    def determine_wants_all(self, refs):
         raise NotImplementedError(self.determine_wants_all)
 
     @staticmethod
@@ -527,7 +513,7 @@ class InterGitNonGitRepository(InterFromGitRepository):
         for revid in set(revids):
             if self.target.has_revision(revid):
                 continue
-            git_sha, mapping = self.source.lookup_bzr_revision_id(revid)
+            git_sha, _mapping = self.source.lookup_bzr_revision_id(revid)
             wants.add(git_sha)
         return self.get_determine_wants_heads(
             wants, include_tags=include_tags, tag_selector=tag_selector
@@ -687,13 +673,15 @@ class InterGitGitRepository(InterFromGitRepository):
         old_refs = self._get_target_either_refs()
         ref_changes = {}
 
-        def determine_wants(heads):
+        def determine_wants(heads, depth=None):
             old_refs = {k: (v, None) for (k, v) in heads.items()}
             new_refs = update_refs(old_refs)
             ret = []
             for name, (sha1, bzr_revid) in list(new_refs.items()):
                 if sha1 is None:
-                    sha1, unused_mapping = self.source.lookup_bzr_revision_id(bzr_revid)
+                    sha1, _unused_mapping = self.source.lookup_bzr_revision_id(
+                        bzr_revid
+                    )
                 new_refs[name] = (sha1, bzr_revid)
                 ret.append(sha1)
             ref_changes.update(new_refs)
@@ -755,7 +743,7 @@ class InterGitGitRepository(InterFromGitRepository):
         for revid in set(revids):
             if revid == NULL_REVISION:
                 continue
-            git_sha, mapping = self.source.lookup_bzr_revision_id(revid)
+            git_sha, _mapping = self.source.lookup_bzr_revision_id(revid)
             wants.add(git_sha)
         return self.get_determine_wants_heads(
             wants, include_tags=include_tags, tag_selector=tag_selector
@@ -876,16 +864,8 @@ class InterLocalGitRemoteGitRepository(InterToGitRepository):
                 ret[name] = gitid
             return ret
 
-        # Wrapper to adapt dulwich Repo.generate_pack_data signature for dulwich >= 0.22
-        # Client expects: (have, want, ofs_delta)
-        # Repo provides: (have, want, progress=None, ofs_delta=None)
-        def generate_pack_data_wrapper(have, want, ofs_delta=True):
-            return self.source._git.generate_pack_data(
-                have, want, progress=None, ofs_delta=ofs_delta
-            )
-
         new_refs = self.target.send_pack(
-            git_update_refs, generate_pack_data_wrapper
+            git_update_refs, self.source._git.generate_pack_data
         )
         return None, self.old_refs, new_refs
 
